# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: models/runtime/stack.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='models/runtime/stack.proto',
  package='runtime',
  syntax='proto3',
  serialized_options=b'Z\"go.jetpack.io/axiom/models/runtime',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1amodels/runtime/stack.proto\x12\x07runtime*7\n\x05Stack\x12\x0e\n\nSTACK_NONE\x10\x00\x12\n\n\x06PYTHON\x10\x01\x12\x06\n\x02GO\x10\x02\x12\n\n\x06NODEJS\x10\x03\x42$Z\"go.jetpack.io/axiom/models/runtimeb\x06proto3'
)

_STACK = _descriptor.EnumDescriptor(
  name='Stack',
  full_name='runtime.Stack',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STACK_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PYTHON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NODEJS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=39,
  serialized_end=94,
)
_sym_db.RegisterEnumDescriptor(_STACK)

Stack = enum_type_wrapper.EnumTypeWrapper(_STACK)
STACK_NONE = 0
PYTHON = 1
GO = 2
NODEJS = 3


DESCRIPTOR.enum_types_by_name['Stack'] = _STACK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: models/core/options.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='models/core/options.proto',
  package='core',
  syntax='proto2',
  serialized_options=b'Z\037go.jetpack.io/axiom/models/core',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19models/core/options.proto\x12\x04\x63ore\x1a google/protobuf/descriptor.proto\"\x1b\n\tDBOptions\x12\x0e\n\x06unique\x18\x02 \x01(\x08\"-\n\x0ePrivacyOptions\x12\x0e\n\x06secret\x18\x01 \x01(\x08\x12\x0b\n\x03pii\x18\x02 \x01(\x08:D\n\ndb_options\x12\x1d.google.protobuf.FieldOptions\x18\xd0\x86\x03 \x01(\x0b\x32\x0f.core.DBOptions:N\n\x0fprivacy_options\x12\x1d.google.protobuf.FieldOptions\x18\xd1\x86\x03 \x01(\x0b\x32\x14.core.PrivacyOptions:/\n\x04type\x12\x1f.google.protobuf.MessageOptions\x18\xb8\x8e\x03 \x01(\tB!Z\x1fgo.jetpack.io/axiom/models/core'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


DB_OPTIONS_FIELD_NUMBER = 50000
db_options = _descriptor.FieldDescriptor(
  name='db_options', full_name='core.db_options', index=0,
  number=50000, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PRIVACY_OPTIONS_FIELD_NUMBER = 50001
privacy_options = _descriptor.FieldDescriptor(
  name='privacy_options', full_name='core.privacy_options', index=1,
  number=50001, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
TYPE_FIELD_NUMBER = 51000
type = _descriptor.FieldDescriptor(
  name='type', full_name='core.type', index=2,
  number=51000, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)


_DBOPTIONS = _descriptor.Descriptor(
  name='DBOptions',
  full_name='core.DBOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unique', full_name='core.DBOptions.unique', index=0,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=96,
)


_PRIVACYOPTIONS = _descriptor.Descriptor(
  name='PrivacyOptions',
  full_name='core.PrivacyOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='secret', full_name='core.PrivacyOptions.secret', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pii', full_name='core.PrivacyOptions.pii', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=143,
)

DESCRIPTOR.message_types_by_name['DBOptions'] = _DBOPTIONS
DESCRIPTOR.message_types_by_name['PrivacyOptions'] = _PRIVACYOPTIONS
DESCRIPTOR.extensions_by_name['db_options'] = db_options
DESCRIPTOR.extensions_by_name['privacy_options'] = privacy_options
DESCRIPTOR.extensions_by_name['type'] = type
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DBOptions = _reflection.GeneratedProtocolMessageType('DBOptions', (_message.Message,), {
  'DESCRIPTOR' : _DBOPTIONS,
  '__module__' : 'models.core.options_pb2'
  # @@protoc_insertion_point(class_scope:core.DBOptions)
  })
_sym_db.RegisterMessage(DBOptions)

PrivacyOptions = _reflection.GeneratedProtocolMessageType('PrivacyOptions', (_message.Message,), {
  'DESCRIPTOR' : _PRIVACYOPTIONS,
  '__module__' : 'models.core.options_pb2'
  # @@protoc_insertion_point(class_scope:core.PrivacyOptions)
  })
_sym_db.RegisterMessage(PrivacyOptions)

db_options.message_type = _DBOPTIONS
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(db_options)
privacy_options.message_type = _PRIVACYOPTIONS
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(privacy_options)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(type)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
